# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

readme = ''

setup(
    long_description=readme,
    name='bio_partitioner',
    version='0.1.0',
    python_requires='==3.*,>=3.7.0',
    author='davidtnfsh',
    author_email='davidtnfsh@gmail.com',
    url = 'https://github.com/david30907d/bio-partitioner',
    license='Apache License 2.0',
    packages=['bio_partitioner'],
    package_dir={"": "."},
    package_data={},
    install_requires=['pyvcf==0.*,>=0.6.8', 'requests==2.*,>=2.23.0'],
    extras_require={
        "dev": [
            "bandit==1.*,>=1.6.2", "black==19.*,>=19.10.0.b0",
            "isort==4.*,>=4.3.21", "mypy==0.*,>=0.770.0", "pylint==2.*,>=2.4.4",
            "pytest==5.*,>=5.4.1", "pytest-cov==2.*,>=2.8.1",
            "safety==1.*,>=1.8.7"
        ]
    },
)
